Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(577)

Unified Diff: components/autofill/core/browser/autofill_experiments.cc

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_experiments.cc
diff --git a/components/autofill/core/browser/autofill_experiments.cc b/components/autofill/core/browser/autofill_experiments.cc
index e066d854f553a70cb1ea3078c5af875c8b5321b0..6ecc864b213db68b6a70b24e1a9b16b574ee1f7a 100644
--- a/components/autofill/core/browser/autofill_experiments.cc
+++ b/components/autofill/core/browser/autofill_experiments.cc
@@ -108,9 +108,9 @@ bool IsCreditCardUploadEnabled(const PrefService* pref_service,
// Users who have enabled a passphrase have chosen to not make their sync
// information accessible to Google. Since upload makes credit card data
// available to other Google systems, disable it for passphrase users.
// We can't determine the passphrase state until the sync backend is
// initialized so disable upload if sync is not yet available.
- if (!sync_service->IsBackendInitialized() ||
+ if (!sync_service->IsEngineInitialized() ||
sync_service->IsUsingSecondaryPassphrase()) {
return false;
}
@@ -108,9 +108,9 @@ bool IsCreditCardUploadEnabled(const PrefService* pref_service,
// information accessible to Google. Since upload makes credit card data
// available to other Google systems, disable it for passphrase users.
- // We can't determine the passphrase state until the sync backend is
+ // We can't determine the passphrase state until the sync engine is
// initialized so disable upload if sync is not yet available.

Powered by Google App Engine
This is Rietveld 408576698